@@ -14,6 +14,9 @@
 
 #include <boost/version.hpp>
 #include <boost/variant.hpp>
+#include <boost/range/size.hpp>
+#include <boost/range/combine.hpp>
+#include <boost/range/adaptor/transformed.hpp>
 
 #include <gudhi/Debug_utils.h>
 #include <gudhi/Alpha_complex_options.h>
@@ -35,8 +38,6 @@
 #include <CGAL/iterator.h>
 #include <CGAL/version.h>  // for CGAL_VERSION_NR
 
-#include <Eigen/src/Core/util/Macros.h>  // for EIGEN_VERSION_AT_LEAST
-
 #include <boost/container/static_vector.hpp>
 
 #include <iostream>
@@ -53,10 +54,6 @@
 # error Alpha_complex_3d is only available for CGAL >= 4.11
 #endif
 
-#if !EIGEN_VERSION_AT_LEAST(3,1,0)
-# error Alpha_complex_3d is only available for Eigen3 >= 3.1.0 installed with CGAL
-#endif
-
 namespace Gudhi {
 
 namespace alpha_complex {
@@ -157,8 +154,10 @@ class Alpha_complex_3d {
     using Kernel = CGAL::Periodic_3_regular_triangulation_traits_3<Predicates>;
   };
 
+ public:
   using Kernel = typename Kernel_3<Predicates, Weighted, Periodic>::Kernel;
 
+ private:
   using TdsVb = typename std::conditional<Periodic, CGAL::Periodic_3_triangulation_ds_vertex_base_3<>,
                                           CGAL::Triangulation_ds_vertex_base_3<>>::type;
 
@@ -277,8 +276,8 @@ Weighted_alpha_complex_3d::Weighted_point_3 wp0(Weighted_alpha_complex_3d::Bare_
   Alpha_complex_3d(const InputPointRange& points) {
     static_assert(!Periodic, "This constructor is not available for periodic versions of Alpha_complex_3d");
 
-    alpha_shape_3_ptr_ = std::unique_ptr<Alpha_shape_3>(
-        new Alpha_shape_3(std::begin(points), std::end(points), 0, Alpha_shape_3::GENERAL));
+    alpha_shape_3_ptr_ = std::make_unique<Alpha_shape_3>(
+        std::begin(points), std::end(points), 0, Alpha_shape_3::GENERAL);
   }
 
   /** \brief Alpha_complex constructor from a list of points and associated weights.
@@ -299,20 +298,15 @@ Weighted_alpha_complex_3d::Weighted_point_3 wp0(Weighted_alpha_complex_3d::Bare_
   Alpha_complex_3d(const InputPointRange& points, WeightRange weights) {
     static_assert(Weighted, "This constructor is not available for non-weighted versions of Alpha_complex_3d");
     static_assert(!Periodic, "This constructor is not available for periodic versions of Alpha_complex_3d");
-    GUDHI_CHECK((weights.size() == points.size()),
+    // FIXME: this test is only valid if we have a forward range
+    GUDHI_CHECK(boost::size(weights) == boost::size(points),
                 std::invalid_argument("Points number in range different from weights range number"));
 
-    std::vector<Weighted_point_3> weighted_points_3;
+    auto weighted_points_3 = boost::range::combine(points, weights)
+      | boost::adaptors::transformed([](auto const&t){return Weighted_point_3(boost::get<0>(t), boost::get<1>(t));});
 
-    std::size_t index = 0;
-    weighted_points_3.reserve(points.size());
-    while ((index < weights.size()) && (index < points.size())) {
-      weighted_points_3.push_back(Weighted_point_3(points[index], weights[index]));
-      index++;
-    }
-
-    alpha_shape_3_ptr_ = std::unique_ptr<Alpha_shape_3>(
-        new Alpha_shape_3(std::begin(weighted_points_3), std::end(weighted_points_3), 0, Alpha_shape_3::GENERAL));
+    alpha_shape_3_ptr_ = std::make_unique<Alpha_shape_3>(
+        std::begin(weighted_points_3), std::end(weighted_points_3), 0, Alpha_shape_3::GENERAL);
   }
 
   /** \brief Alpha_complex constructor from a list of points and an iso-cuboid coordinates.
@@ -356,7 +350,7 @@ Weighted_alpha_complex_3d::Weighted_point_3 wp0(Weighted_alpha_complex_3d::Bare_
 
     // alpha shape construction from points. CGAL has a strange behavior in REGULARIZED mode. This is the default mode
     // Maybe need to set it to GENERAL mode
-    alpha_shape_3_ptr_ = std::unique_ptr<Alpha_shape_3>(new Alpha_shape_3(pdt, 0, Alpha_shape_3::GENERAL));
+    alpha_shape_3_ptr_ = std::make_unique<Alpha_shape_3>(pdt, 0, Alpha_shape_3::GENERAL);
   }
 
   /** \brief Alpha_complex constructor from a list of points, associated weights and an iso-cuboid coordinates.
@@ -388,31 +382,27 @@ Weighted_alpha_complex_3d::Weighted_point_3 wp0(Weighted_alpha_complex_3d::Bare_
                    FT z_min, FT x_max, FT y_max, FT z_max) {
     static_assert(Weighted, "This constructor is not available for non-weighted versions of Alpha_complex_3d");
     static_assert(Periodic, "This constructor is not available for non-periodic versions of Alpha_complex_3d");
-    GUDHI_CHECK((weights.size() == points.size()),
+    // FIXME: this test is only valid if we have a forward range
+    GUDHI_CHECK(boost::size(weights) == boost::size(points),
                 std::invalid_argument("Points number in range different from weights range number"));
     // Checking if the cuboid is the same in x,y and z direction. If not, CGAL will not process it.
     GUDHI_CHECK(
         (x_max - x_min == y_max - y_min) && (x_max - x_min == z_max - z_min) && (z_max - z_min == y_max - y_min),
         std::invalid_argument("The size of the cuboid in every directions is not the same."));
 
-    std::vector<Weighted_point_3> weighted_points_3;
-
-    std::size_t index = 0;
-    weighted_points_3.reserve(points.size());
-
 #ifdef GUDHI_DEBUG
     // Defined in GUDHI_DEBUG to avoid unused variable warning for GUDHI_CHECK
     FT maximal_possible_weight = 0.015625 * (x_max - x_min) * (x_max - x_min);
 #endif
 
-    while ((index < weights.size()) && (index < points.size())) {
-      GUDHI_CHECK((weights[index] < maximal_possible_weight) && (weights[index] >= 0),
-                  std::invalid_argument("Invalid weight at index " + std::to_string(index + 1) +
-                                        ". Must be positive and less than maximal possible weight = 1/64*cuboid length "
-                                        "squared, which is not an acceptable input."));
-      weighted_points_3.push_back(Weighted_point_3(points[index], weights[index]));
-      index++;
-    }
+    auto weighted_points_3 = boost::range::combine(points, weights)
+      | boost::adaptors::transformed([=](auto const&t){
+          auto w = boost::get<1>(t);
+          GUDHI_CHECK((w < maximal_possible_weight) && (w >= 0),
+              std::invalid_argument("Invalid weight " + std::to_string(w) +
+                ". Must be non-negative and less than maximal possible weight = 1/64*cuboid length squared."));
+          return Weighted_point_3(boost::get<0>(t), w);
+          });
 
     // Define the periodic cube
     Dt pdt(typename Kernel::Iso_cuboid_3(x_min, y_min, z_min, x_max, y_max, z_max));
@@ -426,7 +416,7 @@ Weighted_alpha_complex_3d::Weighted_point_3 wp0(Weighted_alpha_complex_3d::Bare_
 
     // alpha shape construction from points. CGAL has a strange behavior in REGULARIZED mode. This is the default mode
     // Maybe need to set it to GENERAL mode
-    alpha_shape_3_ptr_ = std::unique_ptr<Alpha_shape_3>(new Alpha_shape_3(pdt, 0, Alpha_shape_3::GENERAL));
+    alpha_shape_3_ptr_ = std::make_unique<Alpha_shape_3>(pdt, 0, Alpha_shape_3::GENERAL);
   }
 
   /** \brief Inserts all Delaunay triangulation into the simplicial complex.
@@ -471,6 +461,10 @@ Weighted_alpha_complex_3d::Weighted_point_3 wp0(Weighted_alpha_complex_3d::Bare_
 #ifdef DEBUG_TRACES
     std::clog << "filtration_with_alpha_values returns : " << objects.size() << " objects" << std::endl;
 #endif  // DEBUG_TRACES
+    if (objects.size() == 0) {
+      std::cerr << "Alpha_complex_3d create_complex - no triangulation as points are on a 2d plane\n";
+      return false;  // ----- >>
+    }
 
     using Alpha_value_iterator = typename std::vector<FT>::const_iterator;
     Alpha_value_iterator alpha_value_iterator = alpha_values.begin();
