@@ -21,8 +21,8 @@ int main(void) {
   K k;
   std::vector<Point_d> results;
   Gudhi::subsampling::pick_n_random_points(points, 100, std::back_inserter(results));
-  std::cout << "Before sparsification: " << points.size() << " points.\n";
-  std::cout << "After  sparsification: " << results.size() << " points.\n";
+  std::clog << "Before sparsification: " << points.size() << " points.\n";
+  std::clog << "After  sparsification: " << results.size() << " points.\n";
 
   return 0;
 }
